import { Action } from '@ngrx/store';

import { RESTError } from 'packages/core/rest/error';

import { Member } from '../../../../member/model';

export enum ActionType {
  CreateTotp = '[member.totp] CreateTotp',
  CreateTotpSuccess = '[member.totp] CreateTotpSuccess',
  CreateTotpFailure = '[member.totp] CreateTotpFailure',

  Regist = '[member.totp] Regist',
  RegistSuccess = '[member.totp] RegistSuccess',
  RegistFailure = '[member.totp] RegistFailure',
}

export class CreateTotp implements Action {
  readonly type = ActionType.CreateTotp;

  constructor(public payload: {member: Member}) {}
}

export class CreateTotpSuccess implements Action {
  readonly type = ActionType.CreateTotpSuccess;

  constructor(public payload: {key: string, uri: string}) {}
}

export class CreateTotpFailure implements Action {
  readonly type = ActionType.CreateTotpFailure;

  constructor(public payload: RESTError) {}
}

// ----------------------------------------------------------------------------------------

export class Regist implements Action {
  readonly type = ActionType.Regist;

  constructor(public payload: {member: Member, secretCode: string, code: string}) {}
}

export class RegistSuccess implements Action {
  readonly type = ActionType.RegistSuccess;

  constructor(public payload: void) {}
}

export class RegistFailure implements Action {
  readonly type = ActionType.RegistFailure;

  constructor(public payload: RESTError) {}
}

export type Actions =
  | CreateTotp
  | CreateTotpSuccess
  | CreateTotpFailure
  | Regist
  | RegistSuccess
  | RegistFailure
  ;
